@@ -56,7 +56,7 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     coupFreq = pd.read_csv(ruta+'\Equivalencias\coupFreq.csv', sep=';', header=0)
     dateConv = pd.read_csv(ruta+'\Equivalencias\dateConv.csv', sep=';', header=0)
     Nemos = pd.read_excel(ruta+'\Equivalencias\\NEMOS-ISIN.xlsx')
-    Portafolio = pd.read_excel(ruta+'\Insumos\\'+Tipoportafolio+Fecha+'.xlsx')
+    Portafolio = pd.read_excel(ruta+'\Insumos\\'+Tipoportafolio+Fecha+'.xlsx', converters={'FECHA EMISION':str, 'FECHA VENCIMIENTO':str, 'FECHA COMPRA':str})
     Portafolio = Portafolio.replace("[NULL]", np.nan)
     Indices = pd.read_csv(ruta+'\Equivalencias\TIPO_ACTIVO.csv', sep=';', header=0, usecols =["CLASE DE INVERSION","SEC GROUP","SEC TYPE","secDesc2"], encoding='mbcs')
 
@@ -64,11 +64,10 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     Precia.columns=Precia.columns.str.replace(u"á", "a").str.replace(u"é", "e").str.replace(u"í", "i").str.replace(u"ó", "o").str.replace(u"ú", "u")
 
     Columnas351=Columnas["351"].dropna().unique().tolist()
-    Columnasprecia=Columnas["PRECIA"].dropna().unique().tolist()    
+    Columnasprecia=Columnas["PRECIA"].dropna().unique().tolist()
     Portafolio=Portafolio[Columnas351]
     Precia=Precia[Columnasprecia]
 
-
     Portafolio['NUMERO IDENTIFICACION ASIGNADO POR EL CUSTODIO'] = np.where(Portafolio['NUMERO IDENTIFICACION ASIGNADO POR EL CUSTODIO']=="0","NA",Portafolio['NUMERO IDENTIFICACION ASIGNADO POR EL CUSTODIO'])
     Portafolio['NUMERO IDENTIFICACION ASIGNADO POR EL CUSTODIO'] = np.where(Portafolio['NUMERO IDENTIFICACION ASIGNADO POR EL CUSTODIO'].isnull(),"NA",Portafolio['NUMERO IDENTIFICACION ASIGNADO POR EL CUSTODIO'])
     Portafolio['NEMOTECNICO'] = np.where(Portafolio['NEMOTECNICO']=="0","NA",Portafolio['NEMOTECNICO'])
@@ -119,18 +118,20 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     Portafolio['CLASE DE ACCIONES'] = np.where(Portafolio['CLASE DE ACCIONES']=="1","ORD",Portafolio['CLASE DE ACCIONES'])
     Portafolio['CLASE DE ACCIONES'] = np.where(Portafolio['CLASE DE ACCIONES']=="2","PREF",Portafolio['CLASE DE ACCIONES'])
 
+    Portafolio['CLASE DE ACCIONES'] = Portafolio['CLASE DE ACCIONES'].replace('nan', np.nan)
+    Portafolio['CLASE DE ACCIONES'] = Portafolio['CLASE DE ACCIONES'].replace('0', np.nan)    
+
     Portafolio['secDesc2']= np.where(-Portafolio['CLASE DE ACCIONES'].isnull(),Portafolio['CLASE DE ACCIONES'],Portafolio['secDesc2'])
     Portafolio['secDesc2'] = np.where(Portafolio['secDesc2'].isnull(),"NA",Portafolio['secDesc2'])
+
     Portafolio['PRECIO']=np.where(Portafolio['precio'].isnull(),Portafolio['PRECIO'],Portafolio['precio'])
     Portafolio['VALOR NOMINAL RESIDUAL']=np.where(Portafolio['TASA FACIAL DEL TITULO'].isnull(),Portafolio['NUMERO ACCIONES, UNIDADES O PARTICIPACIONES'],Portafolio['VALOR NOMINAL RESIDUAL'])
     Portafolio['cpnFirstActual'] = np.nan
     Portafolio['cpnRateType'] = np.nan
     Portafolio['portfolioNAV'] = np.nan
-    Portafolio['bucketDur'] = np.nan
     Portafolio['country'] = 'CO'
     Portafolio['futureValue'] = np.nan
     Portafolio['referenceDate'] = ref_date
-    
 
     Columnasportafolio=Columnas.loc[:,["COLUMNA FINAL"]]
     Columnasportafolio=Columnasportafolio.drop_duplicates('COLUMNA FINAL').dropna()
@@ -142,6 +143,7 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     Columnasportafolio=Columnasportafolio["COLUMNAS"].dropna().unique().tolist()
     Portafolio.columns=Columnasportafolio
 
+
     # Prorrateo Mkt Value si se requiere. - se modifica logica 2022-09-07
     if mkt_value_prorrateo is not None:
         if port_name == 'PortafolioAlfa':
@@ -167,7 +169,7 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
 
     Portafolio = Portafolio.drop(['codigoPuc'], axis=1)
     Portafolio = Portafolio.drop(['cpnFirstActual'], axis=1)
-    Portafolio = Portafolio.drop(['cpnRateType'], axis=1)    
+    Portafolio = Portafolio.drop(['cpnRateType'], axis=1)
     Portafolio = Portafolio.drop(['margin'], axis=1)
 
 
@@ -182,9 +184,9 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
         Portafolio = Portafolio.append(add_rows).reset_index(drop=True)
 
     # Formateo columnas de fechas.
-    Portafolio['issueDt'] = pd.to_datetime(Portafolio['issueDt'], format='%d%m%Y').dt.strftime("%Y-%m-%d")
-    Portafolio['maturity'] = pd.to_datetime(Portafolio['maturity'], format='%d%m%Y').dt.strftime("%Y-%m-%d")
-    
+    Portafolio['issueDt'] = pd.to_datetime(Portafolio['issueDt'].str.zfill(8), format='%d%m%Y').dt.strftime("%Y-%m-%d")
+    Portafolio['maturity'] = pd.to_datetime(Portafolio['maturity'].str.zfill(8), format='%d%m%Y').dt.strftime("%Y-%m-%d")
+    Portafolio['purchaseDt'] = pd.to_datetime(Portafolio['purchaseDt'].str.zfill(8), format='%d%m%Y').dt.strftime("%Y-%m-%d")
 
     # Completo días al venc. con NA.
     Portafolio=Portafolio.astype({'daysToMaturity':'float'})
@@ -213,7 +215,7 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     # Concateno ambos df.
     Portafolio = pd.concat([df_IBR, df_noIBR], ignore_index=True)
 
-    # Cruzo con NEMOS-ISIN y traigo otros dos campos.    
+    # Cruzo con NEMOS-ISIN y traigo otros dos campos.
     Portafolio = pd.merge(Portafolio, Nemos[['assetId', 'cpnFirstActual', 'cpnRateType']], how='left', on='assetId')
     Portafolio['cpnType'] = ['F' if iR == 'FS' else 'T' if iR != 'FS' and iR is not np.nan else np.nan for iR in Portafolio['indexRate']]
 
@@ -248,11 +250,11 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     PreciaMargen.rename(columns={'Nemo': 'assetId', 'Margen': 'margin', 'Dias al vencimiento': 'Banda'}, inplace=True)
     values=['CDT','BPEDN', 'BPEN']
     filtered_df = Portafolio[Portafolio.secDesc1.isin(values)]
-    filtered_df = pd.merge(filtered_df, PreciaMargen[['assetId', 'Banda', 'margin']],  on=['assetId', 'Banda'], how='left')    
+    filtered_df = pd.merge(filtered_df, PreciaMargen[['assetId', 'Banda', 'margin']],  on=['assetId', 'Banda'], how='left')
     
     # Filtro Portfolio secDesc1 != CDT, BPEDN, o BPEN, y cruzo solo por nemo.
     filtered_df_2 = Portafolio[~Portafolio.secDesc1.isin(values)]
-    filtered_df_2 = pd.merge(filtered_df_2, PreciaMargen[['assetId', 'Banda', 'margin']],  on=['assetId'], how='left')    
+    filtered_df_2 = pd.merge(filtered_df_2, PreciaMargen[['assetId', 'Banda', 'margin']],  on=['assetId'], how='left')
 
     # Concateno ambos resultados.
     Portafolio = pd.concat([filtered_df, filtered_df_2], ignore_index=True)
